============================
The call Function of Serverless Cloud Function
# This is a local tools for SCF.
## Quick Start

First, install the library:

```
$ pip install tencent-serverless-python
```

or download source code from github and install:
```
$ git clone https://github.com/tencentyun/tencent-serverless-python.git
$ cd tencent-serverless-python
$ python setup.py -e .
```
